package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(``P`!````,*8$"#0```!(L@```````#0`(``,
M`"@`'``;``8````T````-(`$"#2`!`B``0``@`$```0````$`````P```+0!
M``"T@00(M($$"!,````3````!`````$````!``````````"`!`@`@`0(E!$`
M`)01```$`````!````$`````(````*`$"`"@!`B@,```H#````4`````$```
M`0````!@````X`0(`.`$"&Q%``!L10``!``````0```!````W*X``-P^!0C<
M/@4(/`(``'@2```&`````!````(```#DK@``Y#X%".0^!0@8`0``&`$```8`
M```$````!````,@!``#(@00(R($$"&P```!L````!`````0```!3Y71D[`$`
M`.R!!`CL@00(*````"@````$````!````%#E=&0PGP``,!\%"#`?!0CL````
M[`````0````$````4>5T9```````````````````````````!@```!````!2
MY71DW*X``-P^!0C</@4()`$``"0!```$`````0```"]L:6(O;&0M;&EN=7@N
M<V\N,@``!````!0````#````1TY5`.Y\=UV7WACKI'(ZWL/49@+)S67?!```
M`!@````%````1TY5``$``<`$`````0````(``<`$`````0````0````0````
M`0```$=.50```````P````(`````````$0```#X````(````"``````<$`0E
M0`2".`%``:"&`8C``0`"2R@$*#BB,D>*```(/@```#\```!"````10```$8`
M``!,````3@```%````!4````5@````````!8````7````%T```!>````````
M``````![\$IK;L7?'\[>1RUK?YI\+L6;MB#_Y`[59-1\V7%8'.)'Q@&L2^/`
MNN.2?,+E/RSZH6Q@LP&+;VH)0]:'^9R!Q+F<0&>OS&8X\HL<0D75[(@'<-/%
MB060#!3BGLG5LG':S>.>,V+;[0PZEPM6I)N66.CM[*?=HVM_J9R;X:<""@J*
M$%>CX/M)`````````````````````#H"`````````````!(```#%`@``````
M```````2````C0$`````````````$@```'P#`````````````!(```"V`@``
M```````````2````X@``````````````$@```"4"`````````````!(```!N
M```````````````2````00(`````````````$@```%4"`````````````!(`
M```^```````````````2````W0``````````````$@```/$!````````````
M`!(```!Z`@`````````````2````5@(`````````````$@````("````````
M`````!(````X`0`````````````2````@0(`````````````$@````8!````
M`````````!(```!\```````````````2````@@$`````````````$@```.@"
M`````````````!(```#$`0`````````````2````'@(`````````````$@``
M`&\!`````````````!(````/`@`````````````2````>P$`````````````
M$@```!0!`````````````!(```"*`@`````````````2`````0``````````
M````(````-L!`````````````!(```"7`@`````````````2````'@``````
M````````$@```#,"`````````````!(```#,`@`````````````2````J0$`
M````````````$@```$T``````````````!(```!9```````````````2````
M+0$`````````````$@````D"`````````````!(```"2`0`````````````2
M````%P(`````````````$@```!```````````````!(```#G````````````
M```2````70(`````````````$@```&0!`````````````!(```"J````````
M```````2````O@(`````````````$@```,8``````````````!(````L`@``
M```````````2````1@$`````````````$@```(X``````````````!(````D
M`0`````````````2````G@(`````````````$@```$<"`````````````!(`
M``#@`0`````````````2````L`$`````````````$@```*,!````````````
M`!(```#H`0`````````````2````:P(`````````````$@```*@"````````
M`````!(```!4`0``P*`$"``````2````A0,``-C.!`@'`0``$@`.`+$#```U
MP`0(_0H``!(`#@#9`@``,*0$"/P!```2``X`60,``'FY!`@%````$@`.`"@$
M``!^N00(QP$``!(`#@!5!```,LL$"*8#```2``X`%`0``!A!!0@`````$``9
M`)@#``!%NP0((````!(`#@#,`0``!.`$"`0````1`!``^P,``%11!0@`````
M$``9`"`$``!TN`0(-````!(`#@`U!```4[\$".(````2``X`1P0``-V^!`A<
M````$@`.`+X#```(004(`````!``&``M````@*,$"``````2````W@(``"!!
M!0@$````$0`9`*4#``!ENP0('P```!(`#@!S`@``*$$%"`0````1`!D`D0,`
M`!A!!0@`````$``8`/$#```4004(!````!$`&`#?`@``($$%"`0````A`!D`
M20,``$+0!`@%````$@`.`/,```#`H@0(`````!(```#A`P``W\\$"&,````2
M``X`Q`,``#"F!`@[````$@`.`,`#```(004(`````"``&`"[````+$$%"`0`
M```1`!D```0```#@!`@$````$0`0`.`"```@004(!````"$`&0!J`P``.;\$
M"!H````2``X`RP,``*BX!`C1````$@`.`)T````P004(`0```!$`&0`'!```
MA+L$"%D#```2``X``%]?9VUO;E]S=&%R=%]?`%!E<FQ?<WES7W1E<FT`4&5R
M;%]S>7-?:6YI=#,`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!0
M97)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T
M`%!E<FQ?<W9?,G!V7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M
M<`!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`4&5R;%]C<F]A:U]M96UO
M<GE?=W)A<`!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL
M;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E
M<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN
M84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L
M;&]C`')E860`7U]E<G)N;U]L;V-A=&EO;@!C;&]S90!O<&5N-C0`<'1H<F5A
M9%]G971S<&5C:69I8P!L<V5E:S8T`%])3U]S=&1I;E]U<V5D`&5X:70`<W1R
M;F-M<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R
M96%L;&]C`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`<W1R
M<W1R`')M9&ER`%]?9G!R:6YT9E]C:&L`;'-T870V-`!?7W-T<FYC<'E?8VAK
M`&]P96YD:7(`<W1D97)R`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`
M<W1R8VAR`')E861D:7(V-`!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S
M`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]R96=I<W1E
M<E]A=&9O<FL`;&EB<&5R;"YS;RXU+C,R+C``;&EB9&PN<V\N,@!L:6)M+G-O
M+C8`;&EB<'1H<F5A9"YS;RXP`&QI8F,N<V\N-@!L:6)C<GEP="YS;RXQ`%]?
M;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!P87)?8F%S96YA;64`
M<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`%]?9&%T85]S=&%R=`!P87)?8W5R
M<F5N=%]E>&5C7W!R;V,`7U]L:6)C7V-S=5]I;FET`&UY7W!A<E]P;`!?96YD
M`%]F<%]H=P!P87)?:6YI=%]E;G8`7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?
M9FEN9'!R;V<`<&%R7W-E='5P7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U])
M;G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXR`$=,24)#7S(N,`!'3$E"0U\R
M+C,N-`!'3$E"0U\R+C,N,@!'3$E"0U\R+C0`1TQ)0D-?,BXS,P`O=7-R+VQI
M8B]P97)L-2\U+C,R+C$O:38X-BUP;&0M;&EN=7@M=&AR96%D+6UU;'1I+T-/
M4D4``````@`"``,``@`"``(``@````(`!```````!0`"``0``@````(`````
M````!@`'``(````"``(````(`````@`"`````@`"``<``````````@`#``(`
M``````@```````(````"``````````D`"``"``,``P`"``(`"`````$``0`!
M``$``0`!``$``0`!``$``0`!``$``0````(``0`"``$``0`"``$````!``$`
M`0````$``@`!``$````!``$``@`A`P``$````#`````2:6D-```'`&L$```0
M````$&EI#0```P!U!`````````$`!@`Q`P``$``````````2:6D-```)`&L$
M```0````=!EI"0``"`!_!```$````'(9:0D```8`BP0``!`````4:6D-```%
M`)<$```0````LY&6!@``!`"A!```$````!!I:0T```(`=00```````#\/P4(
M!AX``"!!!0@%3@``*$$%"`50```L004(!5D``#!!!0@%7@``#$`%"`<!```0
M0`4(!P(``!1`!0@'`P``&$`%"`<$```<0`4(!P4``"!`!0@'!@``)$`%"`<'
M```H0`4(!P@``"Q`!0@'/@``,$`%"`<)```T0`4(!PH``#A`!0@'"P``/$`%
M"`<,``!`0`4(!PT``$1`!0@'#@``2$`%"`</``!,0`4(!Q```%!`!0@'$0``
M5$`%"`<2``!80`4(!Q,``%Q`!0@'%```8$`%"`<5``!D0`4(!Q8``&A`!0@'
M%P``;$`%"`<8``!P0`4(!QD``'1`!0@'&@``>$`%"`<;``!\0`4(!QP``(!`
M!0@''0``A$`%"`<?``"(0`4(!R```(Q`!0@'(0``D$`%"`<B``"40`4(!R,`
M`)A`!0@')```G$`%"`<E``"@0`4(!R8``*1`!0@')P``J$`%"`<H``"L0`4(
M!U4``+!`!0@'*0``M$`%"`<J``"X0`4(!RL``+Q`!0@'+```P$`%"`<M``#$
M0`4(!RX``,A`!0@'+P``S$`%"`<P``#00`4(!S$``-1`!0@',@``V$`%"`<S
M``#<0`4(!TT``.!`!0@'-```Y$`%"`<U``#H0`4(!S8``.Q`!0@'-P``\$`%
M"`<X``#T0`4(!SD``/A`!0@'.@``_$`%"`<[````004(!SP```1!!0@'/0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[[4X/L".AC!@``@</SGP``BX/\____A<!T`O_0@\0(6\,`````````
M``````#_-01`!0C_)0A`!0@`````_R4,0`4(:`````#IX/____\E$$`%"&@(
M````Z=#_____)11`!0AH$````.G`_____R480`4(:!@```#IL/____\E'$`%
M"&@@````Z:#_____)2!`!0AH*````.F0_____R4D0`4(:#````#I@/____\E
M*$`%"&@X````Z7#_____)2Q`!0AH0````.E@_____R4P0`4(:$@```#I4/__
M__\E-$`%"&A0````Z4#_____)3A`!0AH6````.DP_____R4\0`4(:&````#I
M(/____\E0$`%"&AH````Z1#_____)41`!0AH<````.D`_____R5(0`4(:'@`
M``#I\/[___\E3$`%"&B`````Z>#^____)5!`!0AHB````.G0_O___R540`4(
M:)````#IP/[___\E6$`%"&B8````Z;#^____)5Q`!0AHH````.F@_O___R5@
M0`4(:*@```#ID/[___\E9$`%"&BP````Z8#^____)6A`!0AHN````.EP_O__
M_R5L0`4(:,````#I8/[___\E<$`%"&C(````Z5#^____)71`!0AHT````.E`
M_O___R5X0`4(:-@```#I,/[___\E?$`%"&C@````Z2#^____)8!`!0AHZ```
M`.D0_O___R6$0`4(:/````#I`/[___\EB$`%"&CX````Z?#]____)8Q`!0AH
M``$``.G@_?___R600`4(:`@!``#IT/W___\EE$`%"&@0`0``Z<#]____)9A`
M!0AH&`$``.FP_?___R6<0`4(:"`!``#IH/W___\EH$`%"&@H`0``Z9#]____
M):1`!0AH,`$``.F`_?___R6H0`4(:#@!``#I</W___\EK$`%"&A``0``Z6#]
M____);!`!0AH2`$``.E0_?___R6T0`4(:%`!``#I0/W___\EN$`%"&A8`0``
MZ3#]____);Q`!0AH8`$``.D@_?___R7`0`4(:&@!``#I$/W___\EQ$`%"&AP
M`0``Z0#]____)<A`!0AH>`$``.GP_/___R7,0`4(:(`!``#IX/S___\ET$`%
M"&B(`0``Z=#\____)=1`!0AHD`$``.G`_/___R780`4(:)@!``#IL/S___\E
MW$`%"&B@`0``Z:#\____)>!`!0AHJ`$``.F0_/___R7D0`4(:+`!``#I@/S_
M__\EZ$`%"&BX`0``Z7#\____)>Q`!0AHP`$``.E@_/___R7P0`4(:,@!``#I
M4/S___\E]$`%"&C0`0``Z4#\____)?A`!0AHV`$``.DP_/___R7\0`4(:.`!
M``#I(/S___\E`$$%"&CH`0``Z1#\____)01!!0AH\`$``.D`_/__58GE5U93
M@^3P@^Q`BT4,B40D+(M%$(E$)"AEH10```")1"0\,<"-1"0HB40D"(U$)"R)
M1"0$C44(B00DZ,_]___'1"0(P*($",=$)`3`H@0(QP0D@*,$".BZ*P``@#TP
M004(`'4NZ/7\__^C4%$%"(7`#X1S`0``B00DZ$#\__^A+$$%"(D$).@C____
MQH!)!@```*$L004(B00DZ`____^`B)X"```"H2Q!!0B)!"3H^_[__X"(G@(`
M``&+10B#P`4]____/P^'&0$```'``<")!"3HQ_S__XG&HT11!0B+7"0LBP.)
M!L=&!,SA!`BA%$$%"(E&",=&#,_A!`C'!4A1!0@$````BWT(@_\!?AN-0P2-
M5A"-##\!R0'+BPB)"H/`!(/"!#G#=?+'1+X,`````,=$)!``````B70D#(/'
M`XE\)`C'1"0$]K<$"*%0404(B00DZ)7]__^)PX7`=$BA4%$%"(D$).BR^___
MC50D.+B^X`0(Z(T,``"%P'0ZH5!1!0B)!"3H0_O__^@N_?__BT0D/&4K!10`
M``!U6(G8C67T6UY?7<.A4%$%"(D$).BZ_?__B</KIZ%,404(A<!T"HD$).C=
M*```Z[.-5"0XN'7@!`CH+@P``*-,404(A<!TG.O=Z#7]___'!"0!````Z/G[
M___HY/K__V:09I#S#Q[[,>U>B>&#Y/!05%+H(P```('#O)D``(V#0I#__U"-
M@]^/__]045;'P#"D!`A0Z/K[___TBQPDP_,/'OO#BQPDP[@8004(/1A!!0AT
M'+@`````A<!T$U6)Y8/L&,<$)!A!!0C_T(GL7</#N!A!!0@M&$$%"(G"P?H"
MP>@?`=#1^'0@N@````"%TG0758GE@^P8B40D!,<$)!A!!0C_THGL7</#@#TQ
M004(`'4658GE@^P(Z(K____&!3%!!0@!B>Q=P\/KI6:09I!FD&:055=64X'L
M?`$``(G!B40D"&6A%````(F$)&P!```QP(M4@1P/RHE4A"R#P`&#^!!U[HU4
M)"R-C"0L`0``BT(T,T(@,T((,P+1P(E"0(/"!#G*=>F+="0(BQZ+?@2+;@B+
M3@R+1A")1"0<`T0D+(V0F7F"6HG8P<`%`<*)Z#'((?B)SC'(`=")?"00B?K!
MR@*)Z3'1B=\AV3'IB70D&(M<)#`!\X'#F7F"6@'+B<'!P04!RXE\)`R)^<')
M`HG.B=$Q\2'!,=&);"04BWPD-`'O@<>9>8):`?F)W<'%!0'IP<@"B?4QQ8GO
M(=\Q]P-4)#B!PIEY@EH!^HG-P<4%`>K!RP*)Q3'=B>\ASS''`W0D/('&F7F"
M6@'^B=7!Q04![L')`HG=,<V)[R'7,=\#1"1`!9EY@EH!^(GUP<4%`>C!R@*)
MS3'5B>\A]S'/`UPD1('#F7F"6@'[B<7!Q04!Z\'.`HG5,?6)[R'',=<#3"1(
M@<&9>8):`?F)W<'%!0'IP<@"B?4QQ8GO(=\Q]P-4)$R!PIEY@EH!^HG-P<4%
M`>K!RP*)Q3'=B>\ASS''`W0D4('&F7F"6@'^B=7!Q04![L')`HG=,<V)[R'7
M,=\#1"14!9EY@EH!^(GUP<4%`>C!R@*)S3'5B>\A]S'/`UPD6('#F7F"6@'[
MB<7!Q04!Z\'.`HG5,?6)[R'',=<#3"1<@<&9>8):`?F)W<'%!0'IP<@"B?4Q
MQ8GO(=\Q]P-4)&"!PIEY@EH!^HG-P<4%`>K!RP*)Q3'=B>\ASS''`W0D9('&
MF7F"6@'^B=7!Q04![L')`HG=,<V)[R'7,=\#1"1H!9EY@EH!^(GUP<4%`>C!
MR@*)S3'5B>\A]S'/`UPD;('#F7F"6@'[B<7!Q04!Z\'.`HG5,?6)[R'',=<#
M3"1P@<&9>8):`?F)W<'%!0'IP<@"B?4QQ8GO(=\Q]P-4)'2!PIEY@EH!^HG-
MP<4%`>K!RP*)Q3'=B>\ASS''`W0D>('&F7F"6@'WB=7!Q04![\')`@-$)'P%
MH>O9;HG=,<V)[C'6`<:)_<'%!0'NP<H"`YPD@````(V#H>O9;HG+,=,Q^P'#
MB?7!Q04!ZXG]P<T"B>@#C"2$````C;FAZ]ENB=$QZ3'Q`?F)W<'%!0'IP<X"
M`Y0DB````(VZH>O9;HG",?(QV@'ZB<W!Q04!ZL'+`@.$)(P```"-N*'KV6Z)
M]3'=B>@QR`'XB=7!Q04!Z,')`@.T))````"-OJ'KV6Z)W3'-B>XQU@'^B<7!
MQ04![L'*`@.<))0```"-NZ'KV6Z)RS'3,<,!^XGUP<4%`>O!R`(#C"28````
MC;FAZ]ENB=$QP3'Q`?F)W<'%!0'IP<X"`Y0DG````(VZH>O9;HG",?(QV@'Z
MB<W!Q04!ZL'+`@.$)*````"-N*'KV6Z)]3'=B>@QR`'XB=7!Q04!Z,')`@.T
M)*0```"-OJ'KV6Z)W3'-B>XQU@'^B<7!Q04![L'*`@.<)*@```"-NZ'KV6Z)
MRS'3,<,!^XGUP<4%`>O!R`(#C"2L````C;FAZ]ENB=$QP3'Q`?F)W<'%!0'I
MP<X"`Y0DL````(VZH>O9;HG",?(QV@'ZB<W!Q04!ZL'+`@.$)+0```"-N*'K
MV6Z)]3'=B>@QR`'XB=7!Q04!Z,')`@.T)+@```"-OJ'KV6Z)W3'-B>XQU@'^
MB<7!Q04![L'*`@.<)+P```"-NZ'KV6Z)RS'3,<,!^XGUP<4%`>O!R`(#C"3`
M````C;FAZ]ENB=$QP3'Q`?F)W<'%!0'IP<X"`Y0DQ````(VZH>O9;HG",?(Q
MV@'ZB<W!Q04!ZL'+`@.$),@```"-N*'KV6Z)]3'=B>@QR`'XB=7!Q04!Z,')
M`HG="<TAU8G?(<\)[P.T),P```"![B1#Y'`!]XG%P<4%`>_!R@*)S0G5(<6)
MSB'6">X#G"30````@>LD0^1P`=Z)^\'#!0'>P<@"B=4)Q2']B=,APPGK`XPD
MU````('I)$/D<`'+B?'!P04!R\'/`HG%"?TA]8G!(?D)Z0.4)-@```"!ZB1#
MY'`!T8G:P<(%`='!S@*)_0GU(=V)^B'R">H#A"3<````+21#Y'`!PHG-P<4%
M`>K!RP*)]0G=(<V)\"'8">@#O"3@````@>\D0^1P`?B)U<'%!0'HP<D"B=T)
MS2'5B=\ASPGO`[0DY````('N)$/D<`'^B<7!Q04![L'*`HG-"=4AQ8G/(=<)
M[P.<).@```"!ZR1#Y'`!^XGUP<4%`>O!R`*)U0G%(?6)UR''">\#C"3L````
M@>DD0^1P`?F)W<'%!0'IP<X"B<4)]2'=B<<A]PGO`Y0D\````('J)$/D<`'Z
MB<W!Q04!ZL'+`HGU"=TAS8GW(=\)[P.$)/0````M)$/D<`'XB=7!Q04!Z,')
M`HG="<TAU8G?(<\)[P.T)/@```"![B1#Y'`!_HG%P<4%`>[!R@*)S0G5(<6)
MSR'7">\#G"3\````@>LD0^1P`?N)]<'%!0'KP<@"B=4)Q2'UB=<AQPGO`XPD
M``$``('I)$/D<`'YB=W!Q04!Z<'.`HG%"?4AW8G'(?<)[P.4)`0!``"!ZB1#
MY'`!^HG-P<4%`>K!RP*)]0G=(<V)]R'?">\#A"0(`0``+21#Y'`!QXG5P<4%
MB>@!^,')`HG="<TAU8G?(<\)[P.T)`P!``"![B1#Y'`!_HG%P<4%`>[!R@*)
MS0G5(<6)SR'7">\#G"00`0``@>LD0^1P`=^)\\'#!0'[P<@"B=4)Q2'UB=<A
MQPGO`XPD%`$``('I)$/D<`'/B=G!P04!^<'.`HG%"?4AW8G'(?<)[P.4)!@!
M``"!ZB1#Y'`!UXG*P<(%`?K!RP(#A"0<`0``+2H^G36)]3'=B>\QSP''B=7!
MQ04![\')`@.T)"`!``"![BH^G36)W3'-B>@QT`'PB?W!Q04!Z,'*`HG6`YPD
M)`$``(V3UL%BRHG+,?,Q^P'3B<+!P@4!T\'/`@.,)"@!``"!Z2H^G36)\C'Z
M,<(!RHG9P<$%`<J)P<')`@.T)"P!``"-AM;!8LJ)_3'-B>XQW@'&B=7!Q04!
M[L'+`@.\)#`!``"![RH^G36)S3'=B>@QT`'XB?7!Q04!Z,'*`HG7`XPD-`$`
M`(V1UL%BRHG9,?DQ\0'1B<+!P@4!T<'.`@.<)#@!``"!ZRH^G36)^C'R,<(!
MVHG+P<,%`=J)P\'+`@.\)#P!``"-A];!8LJ)]3'=B>\QSP''B=7!Q04![\')
M`@.T)$`!``"![BH^G36)W3'-B>@QT`'PB?W!Q04!Z,'*`HG6`YPD1`$``(V3
MUL%BRHG+,?,Q^P'3B<+!P@4!T\'/`@.,)$@!``"!Z2H^G36)\C'Z,<(!RHG9
MP<$%`<J)P<')`@.T)$P!``"-AM;!8LJ)_3'-B>XQW@'&B=7!Q04![L'+`@.\
M)%`!``"![RH^G36)S3'=B>@QT`'XB?7!Q04!Z,'*`@.,)%0!``"!Z2H^G36)
MW3'5B>\Q]P'/B<'!P04!S\'.`@.<)%@!``"!ZRH^G36)T3'Q,<$!V8G[P<,%
M`=G!R`(#E"1<`0``@>HJ/ITUB?,QPS'[`=.)RL'"!0'3P<\"`[0D8`$``('N
M*CZ=-8G",?HQR@'RB=W!Q04!ZL')`@.$)&0!``"-L-;!8LJ)_3'-B>@QV`'P
MB=7!Q04!Z,'+`HML)`P#K"1H`0``B>Z![BH^G34!]XG-,=V)[C'6`?Z)Q<'%
M!0'NBWPD"(DW`T0D$(G^B4<$P<H"BWPD%(T$.HE&"`-<)!B)7@P#3"0<B4X0
MBX0D;`$``&4K!10```!U"X'$?`$``%M>7UW#Z-?N__]55U93@^PLB50D'(7`
M#X2'````B<:A($$%"(E$)!B%P'1X#[8&A,!T!#P]=3DQ[8M\)!B+'X7;=".)
M;"0(B70D!(D<).A.\?__A<!U!H`\*SUT*8/'!(L?A=MUW8G8@\0L6UY?7<.)
M\8/!`0^V`83`=`0\/77R*?&)S>NSB?HK5"08P?H"BT0D'(D0C4T!`<N)V(/$
M+%M>7UW#,=N)V(/$+%M>7UW#55=64X'LG````(G#9:$4````B80DC````#'`
MA=MT!8`[`'4?BX0DC````&4K!10````/A0L!``"!Q)P```!;7E]=PXD<).CF
M\/__B<:%P'33B30DZ'CP__^%P`^$IP```(UX$X!X$RYU!H!_`0!TX8!X$RX/
MA*,```")'"3H[^[__XG%B3PDZ.7N__\!Q8/%`HDL).AX[O__B<6)?"04B5PD
M$,=$)`P?X`0(QT0D"/_____'1"0$`0```(D$).A^\/__C40D+(E$)`2)+"3H
M?NW__X/X_W00BT0D/"4`\```/0!```!T3HDL).AQ[?__B2PDZ+GL__^)-"3H
MT>___X7`#X59____B30DZ!'P__^)'"3HV>S__^D'____@'\!+@^%4____X!_
M`@`/A"#____I1/___XGHZ,/^__^-="8`ZZWHZ>S__U.![(@```")PV6A%```
M`(E$)'PQP(U$)!R)1"0$B1PDZ)3L__^%P'4TBU0D+('B`/```('Z`$```'0(
M@?H`H```=1S'1"0$`@```(D<).C&[O__A<`/E,`/ML#K`C'`BTPD?&4K#10`
M``!U"('$B````%O#Z'#L__]3@^P8B<.)!"3HHNW__X/H`0'8.<-R#.F"````
M@^@!.<-T'(`X+W3T.<-S<H/H`3G#=`R`."]T(H/H`3G#=?2`.R]T8,<$)"?@
M!`CHL.O__X/$&%O#@#@O=0>#Z`$YPW+T*=B-4`*!^@`0``!W*<=$)`P`$```
M@\`!B40D"(E<)`3'!"1`004(Z./M__^X0$$%"(/$&%O#,<"#Q!A;PSG#=;CK
MF\<$)"7@!`CH4.O__X/$&%O#55=64X'L+!```(G#B=9EH10```")A"0<$```
M,<#'1"0(_P\``(U\)!R)?"0$QP0D*>`$".C2Z___A<!^28UH_X!\!!L`=7>%
M[70[B6PD",=$)`0O````B3PDZ"SM__^%P'0CH2Q!!0B)!"3H&^[__XEL)`R)
M?"0(B5PD!(D$).BW[?__ZQVA+$$%"(D$).CX[?__B70D"(E<)`2)!"3H>.O_
M_XN$)!P0``!E*P44````=0^!Q"P0``!;7E]=PXG%ZXGH].K__U575E.#[#R)
MQXG39:$4````B40D+#'`@#H]=0.#PP&)'"3H#>S__XG%C50D*(GXZ.G[__^)
MQH7`#X37````B00DZ.[K__\YQ0^&M0```(M$)"@!P`'`B40D&`^V!X3`#X1=
M`0``/#T/A%4!``")^(/``0^V$(32=`6`^CUU\2GXBW0D&`,U($$%"(/%`@'H
MB00DZ#WK__^)!H7`=$V+5"0HH2!!!0B+%)"-3P$/M@>(`H3`="$\/74-ZQN$
MP(VT)@````!T$(/"`8/!`0^V0?^(`CP]=>7&`CTQP`^V#`.(3`(!@\`!A,EU
M\8M$)"QE*P44````#X7:````@\0\6UY?7<,QP`^V%`.(%`:#P`&$TG7RZ]6+
M%2!!!0B+,H7V#X2D````,?:)\(/&`8L,LH7)=?2#P`,!P`'`BPU`404(A<EU
M6(E4)!S'!4!1!0@!````B00DZ'KJ__^)P87`=(J-!#8!P(E$)!B)1"0(BU0D
M'(E4)`2)#"2)3"0<Z./H__^+3"0<B0T@004(QT2Q!`````")="0HZ;[^__^)
M1"0$B10DZ!SJ__^)P:,@004(A<`/A#/___^-!#8!P(E$)!CKR3'`Z;?^__^X
M"````#'VZ67____H&NG__X/L+*$L004(B00DZ-KK__^A+$$%"(D$).C-Z___
MQT0D#/CA!`C'1"0(P*`$",=$)`0XX`0(B00DZ&WJ__^A+$$%"(D$).B@Z___
MQT0D%`````#'1"00J>$$",=$)`RIX00(QT0D"#++!`C'1"0$5.`$"(D$).C`
MZO__@\0LPX/L'*$L004(B00DZ%SK___'1"0,^.$$",=$)`C`H`0(QT0D!#C@
M!`B)!"3H_.G__X/$',-75E.![#`@``!EH10```")A"0L(```,<#H^^C__\=$
M)!0TX`0(B40D$,=$)`QIX`0(QT0D"`$0``#'1"0$`0```(U<)"J)'"3H*^O_
M_\=$)`@`$```C;0D*Q```(ET)`2)'"3H4.C__X7`>%R)PXU``8D$).C/Z/__
MA<!T%8G'@_L$<S;VPP)U)O;#`74>Q@08`(N4)"P@``!E*Q44````=2J!Q#`@
M``!;7E_#I.O?9J7VPP%TV&:0Z_*)V<'I`O.E]L,"=,/KYS'`Z\;HE^?__^DJ
M____55=64X'LK!```(N\),`0``"+M"3$$```9:$4````B80DG!```#'`C6PD
M/(GJN'7@!`CHA/C__XG#QT0D!"\```")/"3H:>C__X7`="V)^KA^X`0(Z$7\
M__^)^(N,))P0``!E*PT4````#X50`0``@<2L$```6UY?7<.)/"3H4.C__XE$
M)"S'1"0$B^`$"(DT).A,Z?__B<:%P'2QBT0D+(/``8E$)"R`/@`/A,(```"%
MVW04B70D!(D<).@2YO__A<`/A(,```")-"3H`NC__X!\!O\O=0Z#Z`'&!`8`
M@'P&_R]T\@-$)"P]_P\```^/6?___XE\)!C'1"04)^`$"(ET)!#'1"0,7^$$
M",=$)`@`$```QT0D!`$```"-M"2<````B30DZ'?I__^);"0$B30DZ'OF__^%
MP'40BT0D3"4`\```/0"```!T1\=$)`2+X`0(QP0D`````.B#Z/__B<:%P`^$
MY/[__X`^``^%/O___X7;=`6`.RYT#[XEX`0(N`$```#I6____X![`0!TN^OI
MQT0D!`$```")-"3H(.C__X7`=:6)\KA^X`0(Z.SZ__^)-"3H:.7__^F<_O__
MC78`Z,OE__^+1"0$#[80B<&$TG00@\`!@/HO#T3(#[80A-)U\(G(PXM$)`2%
MP'0*@#@`=`7I*?G__\=$)`0EX`0(Z1SE__]75H/L-&6A%````(E$)"PQP`^W
M!=3A!`AFB40D"HU\)`R^UN$$"+@@````B<'!Z0+SI:@"=`)FI8U4)`2XC>`$
M".AO]O__A<!T)8M$)`0!P`'``P4@004(BU`$B1"%TG37@\`$BU`$B1"%TG7T
MZ\F-5"0$N);@!`CH./;__X7`="6+1"0$`<`!P`,%($$%"(M0!(D0A=)TUX/`
M!(M0!(D0A=)U].O)C50D!+B>X`0(Z`'V__^%P'0EBT0D!`'``<`#!2!!!0B+
M4`2)$(72=->#P`2+4`2)$(72=?3KR8U4)`2XI^`$".C*]?__A<!T)8M$)`0!
MP`'``P4@004(BU`$B1"%TG37@\`$BU`$B1"%TG7TZ\F-5"0$N*[@!`CHD_7_
M_X7`="6+1"0$`<`!P`,%($$%"(M0!(D0A=)TUX/`!(M0!(D0A=)U].O)C50D
M!+B^X`0(Z%SU__^%P'0EBT0D!`'``<`#!2!!!0B+4`2)$(72=->#P`2+4`2)
M$(72=?3KR8U4)`2X=>`$".@E]?__A<!T)8M$)`0!P`'``P4@004(BU`$B1"%
MTG37@\`$BU`$B1"%TG7TZ\F-5"0$N,K@!`CH[O3__X7`="6+1"0$`<`!P`,%
M($$%"(M0!(D0A=)TUX/`!(M0!(D0A=)U].O)C50D!+C4X`0(Z+?T__^%P'0E
MBT0D!`'``<`#!2!!!0B+4`2)$(72=->#P`2+4`2)$(72=?3KR8U4)`2XWN`$
M".B`]/__A<!T)8M$)`0!P`'``P4@004(BU`$B1"%TG37@\`$BU`$B1"%TG7T
MZ\F-5"0$N'[@!`CH2?3__X7`="6+1"0$`<`!P`,%($$%"(M0!(D0A=)TUX/`
M!(M0!(D0A=)U].O)C50D!+CHX`0(Z!+T__^)PH7`=`JXU.`$".CE]___C50D
M!+CYX`0(Z/3S__^)PH7`=`JX".`$".C']___C50D!+@+X00(Z-;S__^)PH7`
M="RX=>`$".BI]___NC?A!`BXKN`$".B:]___BT0D+&4K!10```!U28/$-%Y?
MPXU4)`2X&^$$".B6\___B<*%P'0,N,K@!`CH:??__^N^@7PD&U!!4E]UM(%\
M)!]#3$5!=:IF@7PD(TX]=:&-5"0EZ]'H,^+__X/L'&6A%````(E$)`RA$$$%
M"(/X_W01BTPD#&4K#10```!U,X/$',.-5"0(N,K@!`CH)O/__X7`=!D/MA"`
M^C`/E<$QP(32#Y7`(<BC$$$%".O$,<#K]>C7X?__@^P<Z-_A__^)!"3H)^'_
M_X7`=`*+`(/$',-75E.#[#"+="1`9:$4````B40D+#'`C50D*+BIX00(Z,+R
M__^%P'0'B<.`.`!U(XM$)"QE*P44````#X6;````B?*XJ>$$"(/$,%M>7^EW
M]O__B70D!(D$).B/X/__A<!T%(M$)"QE*P44````=6R#Q#!;7E_#B30DZ'_B
M__^)QXD<).AUXO__`<>#QP*)/"3H".+__XG'B5PD&,=$)!2+X`0(B70D$,=$
M)`Q?X00(QT0D"/_____'1"0$`0```(D$).@&Y/__BT0D+&4K!10```!U!XGZ
MZ6?___]FD.C;X/__55=64X'LG($``(NL)+"!``!EH10```")A"2,@0``,<#'
MA"2\````1>$$",>$),`````EX`0(QX0DQ`````````#'A"38````!.$$",>$
M)-P````3X`0(QX0DX````!;A!`C'A"3D````&^`$",>$).@`````````QX0D
MR````#GA!`C'A"3,````2N$$",>$)-``````````C50D7+AUX`0(Z%WQ__^%
MP'0)@#@`#X4X!```Z#+@__^)!"3H>M___X7`#X2&`P``BQB%VP^$?`,``(D<
M).A`X?__`<"#P`&)!"3HT^#__XG&#[8#A,!T-HGW#[;`B40D$,=$)`Q3X00(
MQT0D"/_____'1"0$`0```(D\).C1XO__@\,!@\<"#[8#A,!US(V\)-@```"X
M".`$".L*@\<$BT?\A<!T+(U4)%SHO/#__XG#A<!TYX`X`'3BZ)KR__^%P)!T
MV(D<).@&W___B<.%P'4\BYPDO````(V\)+P```#K"HM?!(7;=".#QP2`.P!T
M&XG8Z&'R__^%P'3FB1PDZ,[>__^%P'3:B</K`C';B1PDZ&S@__^)QXDT).AB
MX/__`<>!QP0$``")/"3H\M___XE$)#R)="0<QT0D&%CA!`C'1"04)^`$"(E<
M)!#'1"0,7>$$",=$)`C_____QT0D!`$```")QHD$).CDX?__QT0D!,`!``")
M-"3H9.#__X/X_W40Z'K@__^+`(/X$0^%@P(``(U$)%R)1"0$BT0D/(D$).AK
MWO__B<.%P'17BT0D/(E$)!"+10")1"0,QT0D"$#B!`C'1"0$`0```*$H004(
MB00DZ!GA___'1"1``````(N$)(R!``!E*P44````#X5J"```BT0D0('$G($`
M`%M>7UW#BT0D;"4`\```/0!```!UF8MT)'3H-=[__SG&=8R+1"1L)?\!```]
MP`$```^%>/___XD\).CEWO__B40D0(U4)%RX9N$$".@<[___A<`/A#8"``")
M!"3H<]W__XE$)`2+10")!"3H0O;__XE$)$2%P`^$$P(``(M\)$2)/"3H_-[_
M_X/X`W8SC7#\`?Z_:^$$"+D%````\Z8/E\*`V@"$TG48@_@$#X0\!@``BWPD
M1(!\!_LO#X0M!@``H1!!!0B#^/\/A#0$``"%P`^$SP$``+HWX00(N,K@!`CH
M:_+__^@*WO__QT0D'*GA!`B)1"08QT0D%"?@!`B+?"0\B7PD$,=$)`R$X00(
MQT0D"/_____'1"0$`0```(MT)$")-"3H*N#__^M.Z-/>__^#.!%U68/#`>BV
MW?__QT0D(*GA!`B)7"0<B40D&,=$)!0GX`0(B7PD$,=$)`R2X00(QT0D"/__
M___'1"0$`0```(DT).C:W___QT0D!,`!``")-"3H6M[__X/X_W2=BT0D/(D$
M).@IW/__BW0D0(GRN'7@!`CHI?'__XDT).C4^O__Z2O^__^-M"3(````N#GA
M!`CK"HM&!(7`="Z#Q@2-5"1<Z)3M__^%P'3I@#@`=.2)!"3HZMO__XG#A<`/
MA4C\__^+1@2%P'72QP0D#0```.@=W?__B<:[/N$$"+A3````Z4+\__^)1"04
MBT0D/(E$)!"+10")1"0,QT0D"`3B!`C'1"0$`0```*$H004(B00DZ*S>___'
M1"1``````.F._?__B00DB40D/.@F^O__BX0DC($``&4K!10```"+1"0\#X7H
M!0``B80DL($``('$G($``%M>7UWI1=O__XM%`(E$)$3IX?W__\<%$$$%"```
M``#'1"0$`````(M$)$2)!"3HZ]S__XE$)$B%P`^$$?[__\=$)`P"````QT0D
M!.[____'1"0(_____XG&B00DZ/W;___'1"0(!@```(V$)(P!``")1"0$B30D
MZ)+:__^`O"2,`0```'4.@+PDC0$``$,/A$8$``#'1"0,`````,=$)`0`````
MQT0D"`````"+1"1(B00DZ*;;___'A"3L`````2-%9\>$)/````")J\WOQX0D
M]````/[<NIC'A"3X````=E0R$,>$)/P```#PX=+#QX0D``$```````#'A"0$
M`0```````,>$)$@!````````QT0D"`"```"-A"2,`0``B40D!(M$)$B)!"3H
MW]G__XG%A<`/CIP!``"-1"T``<`!P#')`X0D``$```^2P8N4)`0!``"#^0&#
MVO^)A"0``0``B>C!Z!T!T(F$)`0!``"+E"1(`0``C80DC`$``(E$)$2%T@^%
MB````(/]/WY4BTPD1(G+C47`B40D3(G%@^7`C4%``<6Y$````(V\)`@!``")
MWO.EC80D[````.CMW___@\-`.=UUW8M,)$R)R,'H!HU0`<'B!@%4)$3!X`8I
MP8G-QT0D#$0```");"0(BT0D1(E$)`2-A"0(`0``B00DZ+G:__^)K"1(`0``
MZ?_^__^X0````"G0.<4/3L6-C"0(`0```=&)PHG/C;0DC`$``(/X!'-^]L("
M=`)FI8/B`70!I(N4)$@!```!PHF4)$@!``"#^D`/A;3^__\IQ8V,)(P!```!
MR(E$)$2-A"3L````Z#??___I#?___XU4)%RXRN`$".A=ZO__A<`/A(/]__\/
MM@`\,`^$>/W__X3`#X1P_?__QP40004(`0```.F<^___]L$!#X7Q`@``]\<"
M````#X71`@``B='!Z0+SI>EA____BT0D2(D$).B]V___BX0D``$``(G&#\Z+
MG"0$`0``#\O!Z`.#X#^-2`'&A`0(`0``@(/Y.`^.G`$``+A`````C90D"`$`
M``'**<AT#3')Q@0*`(/!`3G!<O6-A"3L````Z'3>__^Y#@```#'`C;PD"`$`
M`/.KB9PD0`$``(FT)$0!``"-A"3L````Z$K>__\/MXPD[````(;IBY0D[```
M`(G0P>@8P>H0B)0D4`$``&:)C"11`0``BY0D\`````_*B90D4P$``(N4)/0`
M```/RHF4)%<!``"+E"3X````#\J)E"1;`0``BY0D_`````_*B90D7P$``(VT
M)&,!``")]XVL)%`!``"-G"2+`0``ZP</MD4`@\4!#[;`B40D$,=$)`Q3X00(
MQT0D"/_____'1"0$`0```(D\).B[VO__@\<".=]UR\:$)(L!````QT0D'*GA
M!`B)="08QT0D%"?@!`B+1"0\B40D$,=$)`QUX00(QT0D"/_____'1"0$`0``
M`(M$)$")!"3H;-K__^FB^O__BVT$A>T/A,CY__^)+"3HA-C__X/X`P^&M_G_
M_X/H!(UT!0"_<.$$"+D%````\Z8/E\`<`(3`#T5L)$2);"1$Z8_Y__^Z.```
M`"G*C;P,"`$``#'`@_H$#X.E````]L("=`)FJX/B`0^$=O[__ZKI</[__X"\
M)(X!``!!#X6L^___@+PDCP$``$,/A9[[__^`O"20`0``2`^%D/O__X"\))$!
M``!%#X6"^___QT0D#`(```#'1"0$QO___\=$)`C_____BW0D2(DT).@HU___
MQT0D""D```"-A"2,`0``B40D!(DT).B]U?__QT0D'*GA!`B-A"2,`0``B40D
M&.G%_O__]\<!````=63WQP(```!U58/Z!`^"0O___XG5@^7\,<F)!`^#P00Y
MZ7+V`<_I*O___P^W#F:)#X/'`H/&`H/J`ND;_?__#[:4)(P!``"(5"1$B!&#
MQP&-M"2-`0``C5#_Z>_\__]FJX/J`NNDJH/J`>N6Z-[5__]55U93@^PL9:$4
M````B40D'*$L004(B00DZ)#8__^)PZ$L004(B00DZ('8__\/MDMDB$AEC50D
M&+BNX`0(Z,7F__^%P'0)@#@Q#X3?`@``Z/[O__^A+$$%"(D$).A-V/__QT0D
M#`L```#'1"0(`0```,=$)`2CX00(B00DZ$W6__^%P`^$Q0```(M`#(MX&(,]
M2%$%"`$/CK(```"^!````#';ZS&+10R)1"0$H411!0B+!#")!"3H8M3__XG"
MH4A1!0B%TG5\C5,!@\8$@\,".<.)TWUMH2Q!!0B)!"3HR]?__\=$)`P`````
MB5PD"(E\)`2)!"3H0]?__X7`=#^+*(M%""4`!"``/0`$``!TE:$L004(B00D
MZ)'7___'1"0,`@```,=$)`@`````B6PD!(D$).@5U?__Z6K___^A2%$%"(U0
M_SG:#X2!`0``H2Q!!0B)!"3H4]?__\=$)`P#````QT0D"`$```#'1"0$J.$$
M"(D$).A3U?__B<.%P'0UBT`,BS"A+$$%"(D$).@;U___QT0D"*KA!`B)="0$
MB00DZ)?4__^+0PR+&/9#"D`/A:X!``"A+$$%"(D$).CKUO__QT0D#`,```#'
M1"0(`0```,=$)`2OX00(B00DZ.O4__^)PX7`=#J-5"08N'[@!`CH$.7__XG&
MA<`/A#P!``"+0PR+&*$L004(B00DZ)O6__^)="0(B5PD!(D$).@;U/__H2Q!
M!0B)!"3H?M;__\=$)`@!````QT0D!+'A!`B)!"3H!M7__XG#H2Q!!0B)!"3H
M5];__\=$)`C&X00(B5PD!(D$).C3T___H2Q!!0B)!"3H-M;__\9`90"-5"08
MN'7@!`CH?>3__XG#HTQ1!0B%P'1QQT0D!,`!``")'"3HV=3__XU0`8/Z`78)
M@_@1#X71````BT0D'&4K!10````/A;L```"#Q"Q;7E]=PX/X`0^.=O[__[L!
M````H2Q!!0B)!"3HQ-7__XE\)`2)!"3HB-+__X/#`3D=2%$%"'_<Z4C^__^A
M1%$%"(D$).CP\?__B<.C3%$%"(7`#X5S____QP0DE.($".@PU/__@'@!``^$
M'/W__^D2_?__H411!0B+,(M##(L8H2Q!!0B)!"3H6-7__XGRB=CHQ.;__^F_
M_O__H2Q!!0B)!"3H/=7__XE<)`2)!"3H4=3__^DT_O__Z%?2__^)1"0,B5PD
M"*%$404(BP")1"0$QP0DN.($".BXT___5U93@^PPBUPD0&6A%````(E$)"PQ
MP(7;#X2/````@#L`#X2&````B=CHFN7__P^V$(G&A-)T$(/``8#Z+P]$\`^V
M$(32=?"A$$$%"(7;#Y7!@_C_=&B%P`^5P"'!A,EU&(M$)"QE*P44````#X60
M````@\0P6UY?PX`[`'3COUCA!`BY!````/.F#Y?`'`"$P'7.BT0D+&4K!10`
M``!U8HG8@\0P6UY?Z5KC___'!"0EX`0(Z`_1___I</___XA,)!^-5"0HN,K@
M!`CHD>+__X7`#[9,)!]T"P^V`(3`=`0\,'4/QP40004(`````.EN____QP40
M004(`0```.E;____Z#'1___S#Q[[55=64X/L+.B!UO__@<,1<```BWPD1(ML
M)$CH_L___XV#X/[__XV3W/[__RG0P?@"B40D''0A,?:);"0(B7PD!(M$)$")
M!"3_E+/<_O__@\8!.70D''7A@\0L6UY?7</S#Q[[P_,/'OM3@^P8Z!S6__^!
MPZQO``"+@PP!``")1"0,BT0D*(E$)`B+1"0DB40D!(M$)"")!"3H(-'__X/$
M&%O#````\P\>^U.#[`CHV]7__X'#:V\``(/$"%O#````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````P````$``@!005)?5$U01$E2`%1%35!$25(`5$U0`"5S+R5S`"X`
M+P`O<')O8R]S96QF+V5X90!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`
M26YT97)N86QS.CI005(Z.D)/3U0`+W!R;V,O)6DO)7,`4$%27U1%35``4$%2
M7U!23T=.04U%`#H`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`
M4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"
M54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$
M25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`4$%27T-,14%.
M/0`Q`%5315(`4UE35$5-`"]T;7``55-%4DY!344`)3`R>`!P87(M`"5S)7,E
M<R5S`%!!5$@`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U
M)7,`)7,E<W1E;7`M)74M)74E<P!!4D=6`!@`<&5R;``P`%!!4CHZ4&%C:V5R
M.CI615)324].`#$N,#0U`"UE`"TM````7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("``````<&5R;'AS:2YC````)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z
M('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E
M;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@``56YA8FQE('1O
M(&-R96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R
M:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI
M"@````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B
M?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA
M9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I
M;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T
M96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP
M.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G
M+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-5
M1D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C
M(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N
M("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE
M;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL
M(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>
M3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D
M7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL
M"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z
M("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM
M>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%2
M3E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA
M<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O
M9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M,3L*=VAI;&4@
M*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D<VEZ93L*<V5E
M:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A:6QE9"!O;B`B
M)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&2"P@)&)U9BP@
M)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O9VYA;64B.B`D
M(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@<FEN9&5X*"1B
M=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P('Q\("1O9F9S
M970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0["B1O9F9S970@
M*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S970@+3T@)&ED
M>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?1D@L("1B=68L
M(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L("1B=68I+"`R
M.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@
M>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B
M3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C
M:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL
M;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY
M("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH
M7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U
M;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@
M(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]T
M96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@
M*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[
M4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1B87-E
M;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z("1F:6QE;F%M
M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B10
M05(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@
M)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E
M860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S
M96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@
M(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T
M>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q
M=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y
M(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@
M9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B
M+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!
M3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/
M.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*
M<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*
M<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE
M*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[8G5F?2D["F]P
M96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A;B=T(')E860@
M)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID
M:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE
M(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?
M<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U
M="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6
M>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S
M96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$
M14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R
M+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@
M(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A
M<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N
M9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[
M4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M
M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'
M5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O
M<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I
M9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I
M9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G
M*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD
M8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@
M/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L
M("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I
M9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%2
M1U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%
M3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2
M.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI
M9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@
M/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*
M07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY
M("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D
M(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R
M(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@
M>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G3454
M02YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@
M<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*
M?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@
M4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2
M*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@
M97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@
M/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@
M24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP
M-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD969I;F5D
M("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@7T9(+"`P
M+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R96%C:"!M
M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y
M?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=
M+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B
M.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A
M9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H)R`G('@@
M*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H+3YP<FEN
M="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER
M92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E
M<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R
M"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE
M("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I
M;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?
M;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I
M<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@
M)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=
M*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]
M"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@
M)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F
M*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H
M(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR
M968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@
M>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F
M:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC
M;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE
M*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT
M*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@
M*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I
M;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H
M*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@
M,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF
M("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B
M/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*
M8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q
M("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%
M(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G
M3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT
M*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70[
M"F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F
M:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&
M2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D
M14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB
M+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T
M7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I
M;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E
M<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H
M*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO
M=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA
M;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE
M*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*
M<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q
M=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E
M<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z
M.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA
M;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@
M4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U
M8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@
M86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D
M,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]
M+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*
M<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D
M("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M
M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I
M9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M
M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF
M("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS
M92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@
M?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M
M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB
M+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6
M>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI
M6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F
M:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@
M97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H
M+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@
M/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE
M=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T
M.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@
M1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@
M)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO
M;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X
M+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92![
M"FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB
M:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*
M?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D
M8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H
M*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@
M(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@
M)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?
M=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D;F%M92P@)&-O
M;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M
M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M
M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG+"`D=&5M<&YA
M;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A(CL*8FEN;6]D
M92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F:#L*8VAM;V0@
M)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E
M;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E
M='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F
M:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%
M?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\
M/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L
M("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D
M<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@
M*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D
M9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@
M*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O9VYA;64@+CT@
M)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS
M<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN
M97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6
M>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\[
M"B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D
M:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O
M9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345]
M.PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@
M>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*
M;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W
M9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#
M=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH
M/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI
M;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P
M87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T]
M(#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141]
M(#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#
M2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E("1%3E9[)U!!
M4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O
M*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@
M:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C
M;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@("(["FEF
M("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]
M"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@
M)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N9W1H*")#3$5!
M3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%2
M7T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE
M=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@
M>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O
M;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#
M;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H
M97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*
M?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF
M4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q
M*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@
M3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N
M86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%
M4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T52
M4D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@
M:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``1L#.^@````<`````('__RP!
M````A?__F`4```"'__\$`0``.X?__Q@!``#0A___4`$```F3__^4`0``KY/_
M__P!``#WE/__/`(``'"5__]D`@``)9;__Z0"``#LEO__Y`(``,:8__\D`P``
M1)G__SP#``!XF?__5`,``$F:__^,`P``3IK__Z`#```5G/__X`,``#6<___T
M`P``5)S__P@$``"MG___.`0```F@__]4!```(Z#__VP$```%H?__M`0```*L
M__\0!0``J*___U`%``"OL/__R`4``!*Q__\$!@``%['__Q@&```4````````
M``%Z4@`!?`@!&PP$!(@!```0````'````/2%__\[`````$0'"!`````P````
M&X;__P4`````````(````$0```#,?___``0````."$8.#$H/"W0$>``_&CLJ
M,B0B0````&@```!XAO__.0L```!!#@B%`D$.#(<#00X0A@1!#A2#!48.D`,#
M)0L*#A1!PPX00<8.#$''#@A!Q0X$00L```!D````K````&V1__^F`````$$.
M"(4"00X,AP-!#A"&!$$.%(,%0PY``EH*#A1!PPX00<8.#$''#@A!Q0X$00MO
M"@X40<,.$$'&#@Q!QPX(0<4.!$$+1PX40<,.$$'&#@Q!QPX(0<4.!#P````4
M`0``JY'__T@!````00X(A0)!#@R'`T$.$(8$00X4@P5&#K`!=`H.%$'##A!!
MQ@X,0<<."$'%#@1!"P`D````5`$``+.2__]Y`````$$."(,"1@Z0`0)K"@X(
M0<,.!$$+````/````'P!```$D___M0````!!#@B#`D,.(`)/"@X(0<,.!$$+
M`D`*#@A!PPX$00M%"@X(0<,.!$$+50X(0<,.!#P```"\`0``>9/__\<`````
M00X(A0)!#@R'`T$.$(8$00X4@P5&#L`@`J\*#A1!PPX00<8.#$''#@A!Q0X$
M00L\````_`$```"4___:`0```$$."(4"00X,AP-!#A"&!$$.%(,%0PY0`O<*
M#A1!PPX00<8.#$''#@A!Q0X$00L`%````#P"``":E?__?@````!##C`">@X$
M%````%0"````EO__-`````!##B!P#@0`-````&P"```<EO__T0````!!#@B'
M`D$.#(8#00X0@P1&#L!``I\*#A!!PPX,0<8."$''#@1!"P`0````I`(``+66
M__\%`````````#P```"X`@``II;__\<!````00X(A0)!#@R'`T$.$(8$00X4
M@P5&#L`A`FL*#A1!PPX00<8.#$''#@A!Q0X$00L0````^`(``"V8__\@````
M`````!`````,`P``.9C__Q\`````````+````"`#``!$F/__60,```!!#@B'
M`D$.#(8#0PY``PD#"@X,0<8."$''#@1!"P``&````%`#``!MF___7`````!#
M#B!D"@X$00L``!0```!L`P``K9O__QH`````0PX@5@X$`$0```"$`P``KYO_
M_^(`````00X(AP)!#@R&`T$.$(,$0PY``D0*#A!!PPX,0<8."$''#@1%"V`*
M#A!!PPX,0<8."$''#@1!"U@```#,`P``29S___T*````00X(A0)!#@R'`T$.
M$(8$00X4@P5&#K"#`@..`@H.%$'##A!!Q@X,0<<."$'%#@1!"P.``@H.%$'#
M#A!!Q@X,0<<."$'%#@1%"P``/````"@$``#JIO__I@,```!!#@B%`D$.#(<#
M00X0A@1!#A2#!4,.0`/#`@H.%$'##A!!Q@X,0<<."$'%#@1!"T0```!H!```
M4*K__P<!````00X(AP)!#@R&`T$.$(,$0PY``F\*#A!!PPX,0<8."$''#@1!
M"VP*#A!!PPX,0<8."$''#@1%"RP```"P!```8'____P!````00X(A0)"#05)
MAP.&!(,%`YD!"L-!QD''0<4,!`1!"S@```#@!```WZK__V,`````10X(A0)!
M#@R'`T$.$(8$00X4@P5##D`"4PX40<,.$$'&#@Q!QPX(0<4.!!`````<!0``
M!JO__P4`````````'````#`%``#WJO__/@````!%#@B#`D,.('0."$'##@0`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````/:F!`C6I@0(`0``
M`/H"```!````#`,```$````7`P```0```"$#```!````,0,```$````[`P``
M#P```*P$```,`````*`$"`T```"(T`0(&0```-P^!0@;````!````!H```#@
M/@4('`````0```#U_O]O-(($"`4````PB00(!@```#"#!`@*````XP0```L`
M```0````%0`````````#`````$`%"`(```#X`0``%````!$````7````G(\$
M"!$```!TCP0($@```"@````3````"````/[__V_4C@0(____;P(```#P__]O
M%(X$"```````````````````````````````````````````````````````
M``````````````#D/@4(``````````!&H`0(5J`$"&:@!`AVH`0(AJ`$"):@
M!`BFH`0(MJ`$",:@!`C6H`0(YJ`$"/:@!`@&H00(%J$$"":A!`@VH00(1J$$
M"%:A!`AFH00(=J$$"(:A!`B6H00(IJ$$"+:A!`C&H00(UJ$$".:A!`CVH00(
M!J($"!:B!`@FH@0(-J($"$:B!`A6H@0(9J($"':B!`B&H@0(EJ($"*:B!`BV
MH@0(QJ($"-:B!`CFH@0(]J($"`:C!`@6HP0()J,$"#:C!`A&HP0(5J,$"&:C
M!`AVHP0(AJ,$"):C!`BFHP0(MJ,$",:C!`C6HP0(YJ,$"/:C!`@&I`0(%J0$
M"":D!`@``````````/_____\X@0(1T-#.B`H4$Q$+4QI;G5X*2`Q,"XS+C`@
M,C`R,3`T,#@@*')E;&5A<V4I```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG
M;G4N8G5I;&0M:60`+FYO=&4N9VYU+G!R;W!E<G1Y`"YN;W1E+D%"22UT86<`
M+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV
M97)S:6]N7W(`+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`
M+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N
M9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YG;W0N<&QT`"YD871A`"YB<W,`
M+F-O;6UE;G0`````````````````````````````````````````````````
M```````+`````0````(```"T@00(M`$``!,```````````````$`````````
M$P````<````"````R($$",@!```D```````````````$`````````"8````'
M`````@```.R!!`CL`0``*```````````````!``````````Y````!P````(`
M```4@@0(%`(``"````````````````0`````````1P```/;__V\"````-(($
M"#0"``#\````!@`````````$````!````%$````+`````@```#"#!`@P`P``
M``8```<````!````!````!````!9`````P````(````PB00(,`D``.,$````
M``````````$`````````80```/___V\"````%(X$"!0.``#`````!@``````
M```"`````@```&X```#^__]O`@```-2.!`C4#@``H`````<````"````!```
M``````!]````"0````(```!TCP0(=`\``"@````&``````````0````(````
MA@````D```!"````G(\$")P/``#X`0``!@```!<````$````"````(\````!
M````!@````"@!`@`(```)```````````````!`````````"*`````0````8`
M```PH`0(,"`````$`````````````!`````$````E0````$````&````,*0$
M"#`D``!5+``````````````0`````````)L````!````!@```(C0!`B(4```
M&```````````````!`````````"A`````0````(`````X`0(`&```#`_````
M``````````0`````````J0````$````"````,!\%"#"?``#L````````````
M```$`````````+<````!`````@```!P@!0@<H```4`4`````````````!```
M``````#!````#@````,```#</@4(W*X```0```````````````0````$````
MS0````\````#````X#X%"."N```$```````````````$````!````-D````&
M`````P```.0^!0CDK@``&`$```<`````````!`````@```#B`````0````,`
M``#\/P4(_*\```0```````````````0````$````YP````$````#`````$`%
M"`"P```(`0`````````````$````!````/`````!`````P````A!!0@(L0``
M$```````````````!`````````#V````"`````,````@004(&+$``#00````
M`````````"``````````^P````$````P`````````!BQ```K````````````
M```!`````0````$````#``````````````!#L0``!`$``````````````0``
%````````
